aboutsummaryrefslogtreecommitdiff
path: root/src/main.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/main.rs')
-rw-r--r--src/main.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/main.rs b/src/main.rs
index 938f851..be87630 100644
--- a/src/main.rs
+++ b/src/main.rs
@@ -146,10 +146,10 @@ struct ConfigNet6 {
fn main() -> Result<()> {
// Get the config path from the first command-line argument
// or fall back to the default /etc/dyndns.conf.
let config_path = env::args()
.nth(1)
- .unwrap_or_else(|| String::from("/etc/dyndns.conf"));
+ .unwrap_or_else(|| String::from("/data/dyndns.conf"));
let mut config_file = File::open(config_path.as_str())?;
@@ -146,10 +146,10 @@ struct ConfigNet6 {
fn main() -> Result<()> {
// Get the config path from the first command-line argument
- // or fall back to the default /etc/dyndns.conf.
+ // or fall back to the default /data/dyndns.conf.
let config_path = env::args()
.nth(1)